@@ -1,35 +1,43 @@
 # This file is part of the MapProxy project.
 # Copyright (C) 2010 Omniscale <http://omniscale.de>
 # 
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Affero General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
 # 
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU Affero General Public License for more details.
+#    http://www.apache.org/licenses/LICENSE-2.0
 # 
-# You should have received a copy of the GNU Affero General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
 
 from __future__ import with_statement
 
-import os
 import sys
-import shutil
+import logging
 
 from optparse import OptionParser
-from textwrap import dedent
 from mapproxy.util import local_base_config
-from mapproxy.config.loader import load_configuration
+from mapproxy.config.loader import load_configuration, ConfigurationError
 from mapproxy.seed.config import load_seed_tasks_conf
 from mapproxy.seed.seeder import seed
 from mapproxy.seed.cleanup import cleanup
 from mapproxy.seed.util import format_seed_task, format_cleanup_task
 
 
+def setup_logging():
+    mapproxy_log = logging.getLogger('mapproxy')
+    mapproxy_log.setLevel(logging.WARN)
+
+    ch = logging.StreamHandler(sys.stdout)
+    ch.setLevel(logging.DEBUG)
+    formatter = logging.Formatter(
+        "[%(asctime)s] %(name)s - %(levelname)s - %(message)s")
+    ch.setFormatter(formatter)
+    mapproxy_log.addHandler(ch)
+
 class SeedScript(object):
     usage = "usage: %prog [options] seed_conf"
     parser = OptionParser(usage)
@@ -81,14 +89,24 @@ class SeedScript(object):
     
         if not options.conf_file:
             self.parser.error('missing mapproxy configuration -f/--proxy-conf')
-    
-        mapproxy_conf = load_configuration(options.conf_file, seed=True)
+
+        setup_logging()
+        
+        try:
+            mapproxy_conf = load_configuration(options.conf_file, seed=True)
+        except ConfigurationError, ex:
+            print "ERROR: " + '\n\t'.join(str(ex).split('\n'))
+            sys.exit(2)
 
         with local_base_config(mapproxy_conf.base_config):
-            seed_conf = load_seed_tasks_conf(options.seed_file, mapproxy_conf)
-            seed_names, cleanup_names = self.task_names(seed_conf, options)
-            seed_tasks = seed_conf.seeds(seed_names)
-            cleanup_tasks = seed_conf.cleanups(cleanup_names)
+            try:
+                seed_conf = load_seed_tasks_conf(options.seed_file, mapproxy_conf)
+                seed_names, cleanup_names = self.task_names(seed_conf, options)
+                seed_tasks = seed_conf.seeds(seed_names)
+                cleanup_tasks = seed_conf.cleanups(cleanup_names)
+            except ConfigurationError, ex:
+                print "error in configuration: " + '\n\t'.join(str(ex).split('\n'))
+                sys.exit(2)
 
             if options.summary:
                 print '========== Seeding tasks =========='
@@ -192,68 +210,5 @@ def split_comma_seperated_option(option):
             result.extend(args.split(','))
     return result
 
-def cleanup_main():
-    print "#" *65
-    print "# Warning: This script is deprecated."
-    print "# Please use the mapproxy-seed tool with the cleanup options."
-    print "#" *65
-    
-    usage  = "usage: %prog [options] caches"
-    usage += dedent("""\n
-     Removes cached data from one or more caches.
-     
-     Examples
-       Remove level 10 and above (11, 12, 13, ...)
-         $ %prog cache_EPSG4326 --from 10
-       Remove level 8 - 10
-         $ %prog cache_EPSG4326 --from 8 --to 10
-       Remove all levels
-         $ %prog cache_EPSG4326 --all
-
-     Note: You need to point %prog directly to one (or more)
-           cache directories (e.g. var/cache_data/cache_*).
-           TODO: Support for mapproxy.yaml.""")
-    
-    parser = OptionParser(usage)
-    parser.add_option("--from", type="int", metavar='n',
-                      dest="from_level", default=None,
-                      help="remove from this level (inclusive)")
-    parser.add_option("--to", type="int", metavar='n',
-                      dest="to_level", default=None,
-                      help="remove to this level (inclusive)")
-    parser.add_option("-n", "--dry-run",
-                      action="store_true", dest="dry_run", default=False,
-                      help="do not remove anything, just print output what"
-                      " would be removed")
-    parser.add_option("-a", "--all",
-                      action="store_true", dest="remove_all", default=False,
-                      help="remove all levels")
-    
-    (options, args) = parser.parse_args()
-    if len(args) == 0:
-        parser.error('need one cache directory (see --help)')
-    
-    if not options.from_level and not options.to_level and not options.remove_all:
-        parser.error('need --from or/and --to (use --all to remove all levels)')
-
-    for cache_dir in args:
-        remove_levels(cache_dir, options.from_level, options.to_level, options.dry_run)
-
-def remove_levels(cache_dir, from_level, to_level, dry_run=True):
-    if from_level is None:
-        from_level = 0
-    if to_level is None:
-        to_level = 1e99
-    
-    for filename in os.listdir(cache_dir):
-        level_dir = os.path.join(cache_dir, filename)
-        if os.path.isdir(level_dir) and filename.isdigit():
-            level = int(filename, 10)
-            if from_level <= level <= to_level:
-                print 'rm -r %s' % os.path.join(cache_dir, filename)
-                if not dry_run:
-                    shutil.rmtree(level_dir)
-
-
 if __name__ == '__main__':
     main()
